@@ -12,9 +12,10 @@ from pymodelextractor.exceptions.number_of_states_exceeded_exception import Numb
 from pymodelextractor.utils.time_bound_utilities import timeout
 from pymodelextractor.learners.observation_table_learners.observation_table import epsilon
 from pythautomata.automata.wheighted_automaton_definition.weighted_state import WeightedState
+import numpy as np
 
 class BoundedPDFAQuantizationNAryTreeLearner(PDFAQuantizationNAryTreeLearner):
-    def __init__(self, partitioner, max_states, max_query_length, max_seconds_run=None, generate_partial_hipothesis = False, pre_cache_queries_for_building_hipothesis = False, check_probabilistic_hipothesis = True, exhaust_counterexample = False):
+    def __init__(self, partitioner, max_states, max_query_length, max_seconds_run=None, generate_partial_hipothesis = False, pre_cache_queries_for_building_hipothesis = False, check_probabilistic_hipothesis = True, exhaust_counterexample = False, mean_distribution_for_partial_hipothesis = False):
         super().__init__(partitioner, pre_cache_queries_for_building_hipothesis, check_probabilistic_hipothesis, exhaust_counterexample)
         self._max_states = max_states
         self._max_query_length = max_query_length
@@ -24,6 +25,7 @@ class BoundedPDFAQuantizationNAryTreeLearner(PDFAQuantizationNAryTreeLearner):
         self._exceded_time_bound = False
         self._history = []        
         self._generate_partial_hipothesis = generate_partial_hipothesis
+        self._compute_mean_distribution_for_partial_hipothesis = mean_distribution_for_partial_hipothesis
         
 
     def _perform_equivalence_query(self, model):
@@ -87,6 +89,7 @@ class BoundedPDFAQuantizationNAryTreeLearner(PDFAQuantizationNAryTreeLearner):
             state = WeightedState(leaf_str, initial_weight, terminal_symbol_probability)
             states[leaf_str] = state
         unknown_state =  WeightedState(self._tree.unknown_leaf, 0, -1)     
+        partial_distributions = []
         states[self._tree.unknown_leaf] = unknown_state
         accessed_states = set()
         for access_string, state in states.items():
@@ -96,10 +99,18 @@ class BoundedPDFAQuantizationNAryTreeLearner(PDFAQuantizationNAryTreeLearner):
                     if access_string_of_transition != access_string:
                         accessed_states.add(access_string_of_transition)
                     state.add_transition(symbol, states[access_string_of_transition],
-                                            self._tree.leaves[access_string].probabilities[symbol])        
+                                            self._tree.leaves[access_string].probabilities[symbol]) 
+                    if access_string_of_transition == self._tree.unknown_leaf:
+                        partial_distributions.append(self._tree._next_token_probabilities(access_string + symbol))
         
-        for symbol in symbols:
-            states[self._tree.unknown_leaf].add_transition(symbol, states[self._tree.unknown_leaf], -1)
+        if self._compute_mean_distribution_for_partial_hipothesis:
+            for symbol in symbols:
+                mean_symbol_dist = np.mean([prob[symbol] for prob in partial_distributions])
+                states[self._tree.unknown_leaf].add_transition(symbol, states[self._tree.unknown_leaf], mean_symbol_dist)
+            states[self._tree.unknown_leaf].final_weight = np.mean([prob[self.terminal_symbol] for prob in partial_distributions])
+        else:
+            for symbol in symbols:
+                states[self._tree.unknown_leaf].add_transition(symbol, states[self._tree.unknown_leaf], -1)
 
         for state in list(states.keys()).copy():
             if state not in accessed_states and states[state].initial_weight != 1:
